Index: /tags/ipp-20100701/pstamp/scripts/pstamp_job_run.pl
===================================================================
--- /tags/ipp-20100701/pstamp/scripts/pstamp_job_run.pl	(revision 28880)
+++ /tags/ipp-20100701/pstamp/scripts/pstamp_job_run.pl	(revision 28881)
@@ -93,6 +93,14 @@
 
     $argString .= " -file $params->{image}";
-    $argString .= " -mask $params->{mask}";
-    my @file_list = ($params->{image}, $params->{mask});
+    my @file_list = ($params->{image});
+    
+    my $nan_masked = 1;
+    if (!$params->{magicked}) {
+        $nan_masked = 0;
+    }
+    if ($nan_masked or ($options & $PSTAMP_SELECT_MASK)) {
+        $argString .= " -mask $params->{mask}";
+        push @file_list, $params->{mask};
+    }
     if ($options & $PSTAMP_SELECT_VARIANCE) {
         $argString .= " -variance $params->{weight}";
Index: /tags/ipp-20100701/pstamp/scripts/pstampparse.pl
===================================================================
--- /tags/ipp-20100701/pstamp/scripts/pstampparse.pl	(revision 28880)
+++ /tags/ipp-20100701/pstamp/scripts/pstampparse.pl	(revision 28881)
@@ -386,9 +386,10 @@
     $need_magic    = $proj_hash->{need_magic};
 
     # Temporary hack so that MOPS can get at non-magicked data
     my $allow_mops_unmagicked = 1;
     if ($allow_mops_unmagicked) {
         if ($product and (($product eq "mops-pstamp-results") or
-                          ($product eq "mops-pstamp-results2"))) {
+                          ($product eq "mops-pstamp-results2") or
+			  ($product eq "ifa-pstamp-results"))) {
             $need_magic = 0;
         }
@@ -814,4 +815,12 @@
         ($stage ne 'chip' and $state eq 'full')) {
         my_die("$stage $stage_id is in unexpected state $state", $PS_EXIT_PROG_ERROR);
+    }
+
+    if (($stage eq 'diff') and ($stage_id <= 22778)) {
+    	print STDERR "diff_id $stage_id cannot be updated\n";
+	$$r_dep_id = 0;
+	$$r_fault = $PSTAMP_GONE;
+	$$r_jobState = 'stop';
+	return;
     }
 
@@ -386,9 +386,10 @@
     $need_magic    = $proj_hash->{need_magic};
 
-    # Temporary hack so that MOPS can get at non-magicked data
+    # Temporary hack so that IFA can get at non-magicked data
     my $allow_mops_unmagicked = 1;
     if ($allow_mops_unmagicked) {
